@@ -306,6 +306,7 @@ gfbgraph_node_new_from_id (GFBGraphAuthorizer *authorizer, const gchar *id, GTyp
                 g_object_unref (jparser);
         }
 
+        g_object_unref (rest_call);
         return node;
 }
 
@@ -373,6 +374,25 @@ gfbgraph_node_get_updated_time (GFBGraphNode *node)
         return node->priv->updated_time;
 }
 
+/**
+ * gfbgraph_node_set_id:
+ * @node: a #GFBGraphNode.
+ * @id: a const pointer to a #gchar.
+ *
+ * Sets the ID for a node. Just useful when a new node is created
+ * and the Graph API returns the ID of the new created node.
+ **/
+void
+gfbgraph_node_set_id (GFBGraphNode *node, const gchar *id)
+{
+        g_return_if_fail (GFBGRAPH_IS_NODE (node));
+        g_return_if_fail (id != NULL);
+
+        g_object_set (G_OBJECT (node),
+                      "id", id,
+                      NULL);
+}
+
 /**
  * gfbgraph_node_get_connection_nodes:
  * @node: a #GFBGraphNode object which retrieve the connected nodes.
@@ -424,19 +444,18 @@ gfbgraph_node_get_connection_nodes (GFBGraphNode *node, GType node_type, GFBGrap
                                          gfbgraph_connectable_get_connection_path (GFBGRAPH_CONNECTABLE (connected_node),
                                                                                       G_OBJECT_TYPE (node)));
         rest_proxy_call_set_function (rest_call, function_path);
+        g_free (function_path);
 
         if (rest_proxy_call_sync (rest_call, error)) {
                 const gchar *payload;
 
                 payload = rest_proxy_call_get_payload (rest_call);
                 nodes_list = gfbgraph_connectable_parse_connected_data (GFBGRAPH_CONNECTABLE (connected_node), payload, error);
-        } else {
-                return NULL;
         }
 
         /* We don't need this node again */
-        g_clear_object (&connected_node);
-        g_free (function_path);
+        g_object_unref (connected_node);
+        g_object_unref (rest_call);
 
 
         return nodes_list;
@@ -530,14 +549,29 @@ gfbgraph_node_append_connection (GFBGraphNode *node, GFBGraphNode *connect_node,
         RestProxyCall *rest_call;
         GHashTable *params;
         gchar *function_path;
+        gboolean success;
 
         g_return_val_if_fail (GFBGRAPH_IS_NODE (node), FALSE);
         g_return_val_if_fail (GFBGRAPH_IS_NODE (connect_node), FALSE);
         g_return_val_if_fail (GFBGRAPH_IS_AUTHORIZER (authorizer), FALSE);
-        /* TODO: Check if connect_node is connectable to node */
+
+        if (GFBGRAPH_IS_CONNECTABLE (connect_node) == FALSE) {
+                g_set_error (error, GFBGRAPH_NODE_ERROR,
+                             GFBGRAPH_NODE_ERROR_NO_CONNECTABLE,
+                             "The given node type (%s) doesn't implement connectable interface", G_OBJECT_TYPE_NAME (connect_node));
+                return FALSE;
+        }
+
+        if (gfbgraph_connectable_is_connectable_to (GFBGRAPH_CONNECTABLE (connect_node), G_OBJECT_TYPE (node)) == FALSE) {
+                g_set_error (error, GFBGRAPH_NODE_ERROR,
+                             GFBGRAPH_NODE_ERROR_NO_CONNECTABLE,
+                             "The given node type (%s) can't append a %s connection", G_OBJECT_TYPE_NAME (node), G_OBJECT_TYPE_NAME (connect_node));
+                return FALSE;
+        }
 
         priv = GFBGRAPH_NODE_GET_PRIVATE (node);
 
+        success = FALSE;
         rest_call = gfbgraph_new_rest_call (authorizer);
         rest_proxy_call_set_method (rest_call, "POST");
         function_path = g_strdup_printf ("%s/%s",
@@ -545,6 +579,7 @@ gfbgraph_node_append_connection (GFBGraphNode *node, GFBGraphNode *connect_node,
                                          gfbgraph_connectable_get_connection_path (GFBGRAPH_CONNECTABLE (connect_node),
                                                                                    G_OBJECT_TYPE (node)));
         rest_proxy_call_set_function (rest_call, function_path);
+        g_free (function_path);
 
         params = gfbgraph_connectable_get_connection_post_params (GFBGRAPH_CONNECTABLE (connect_node), G_OBJECT_TYPE (node));
         if (g_hash_table_size (params) > 0) {
@@ -560,14 +595,27 @@ gfbgraph_node_append_connection (GFBGraphNode *node, GFBGraphNode *connect_node,
 
         if (rest_proxy_call_sync (rest_call, error)) {
                 const gchar *payload;
+                JsonParser *jparser;
+                JsonNode *jnode;
+                JsonReader *jreader;
 
                 payload = rest_proxy_call_get_payload (rest_call);
-                /* TODO: Parse result (the ID) and put to the connect_node */
-        } else {
-                return FALSE;
+                /* Parssing the new ID */
+                jparser = json_parser_new ();
+                json_parser_load_from_data (jparser, payload, -1, error);
+                jnode = json_parser_get_root (jparser);
+                jreader = json_reader_new (jnode);
+
+                json_reader_read_element (jreader, 0);
+                gfbgraph_node_set_id (connect_node,
+                                      json_reader_get_string_value (jreader));
+                json_reader_end_element (jreader);
+
+                g_object_unref (jreader);
+                g_object_unref (jparser);
+                success = TRUE;
         }
+        g_object_unref (rest_call);
 
-        g_free (function_path);
-
-        return TRUE;
+        return success;
 }
