@@ -2,6 +2,7 @@
 /*
  * libgfbgraph - GObject library for Facebook Graph API
  * Copyright (C) 2013-2015 Álvaro Peña <alvaropg@gmail.com>
+ *                    2019 Leesoo Ahn <yisooan@fedoraproject.org>
  *
  * GFBGraph is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -44,9 +45,9 @@ struct _GFBGraphTestApp
         gchar *access_token;
 };
 
-#define FACEBOOK_ENDPOINT "https://graph.facebook.com/v2.3"
+#define FACEBOOK_ENDPOINT "https://graph.facebook.com/v2.10"
 
-#define FACEBOOK_TEST_USER_PERMISSIONS "user_about_me,user_photos,email"
+#define FACEBOOK_TEST_USER_PERMISSIONS "email,user_about_me,user_photos,publish_actions"
 
 GFBGraphTestApp*
 gfbgraph_test_app_setup (void)
@@ -54,14 +55,14 @@ gfbgraph_test_app_setup (void)
         GFBGraphTestApp *app;
         RestProxy *proxy;
         RestProxyCall *rest_call;
-        gchar *function_path;
-        GKeyFile *app_key_file;
-        gchar *app_key_filename;
-        GError *error = NULL;
-        const char *payload;
+        g_autofree gchar *function_path = NULL;
+        g_autofree gchar *app_key_filename = NULL;
+        g_autoptr(GError) error = NULL;
+        g_autoptr(GKeyFile) app_key_file = NULL;
+        g_autoptr(JsonParser) jparser = NULL;
+        g_autoptr(JsonReader) jreader = NULL;
         JsonNode *jnode;
-        JsonParser *jparser;
-        JsonReader *jreader;
+        const char *payload;
 
         app_key_filename = g_test_build_filename (G_TEST_BUILT,
                                                   "credentials.ini",
@@ -109,7 +110,6 @@ gfbgraph_test_app_setup (void)
         json_reader_read_element (jreader, 0);
         app->access_token = g_strdup(json_reader_get_string_value (jreader));
         json_reader_end_element (jreader);
-        g_object_unref(jparser);
 
         g_clear_object(&rest_call);
         g_clear_object(&proxy);
@@ -122,13 +122,13 @@ gfbgraph_test_fixture_setup (GFBGraphTestFixture *fixture, gconstpointer user_da
 {
         RestProxy *proxy;
         RestProxyCall *rest_call;
-        gchar *function_path;
+        g_autofree gchar *function_path = NULL;
         const gchar *payload;
-        GError *error = NULL;
+        g_autoptr(GError) error = NULL;
         const GFBGraphTestApp *app = user_data;
         JsonNode *jnode;
-        JsonParser *jparser;
-        JsonReader *jreader;
+        g_autoptr(JsonParser) jparser = NULL;
+        g_autoptr(JsonReader) jreader = NULL;
         const gchar *access_token;
 
         /* Create a new user */
@@ -159,7 +159,7 @@ gfbgraph_test_fixture_setup (GFBGraphTestFixture *fixture, gconstpointer user_da
         fixture->user_id = g_strdup (json_reader_get_string_value (jreader));
         json_reader_end_element (jreader);
         json_reader_read_element (jreader, 1);
-        access_token = g_strdup (json_reader_get_string_value (jreader));
+        access_token = json_reader_get_string_value (jreader);
         json_reader_end_element (jreader);
         json_reader_read_element (jreader, 3);
         fixture->user_email = g_strdup (json_reader_get_string_value (jreader));
@@ -167,22 +167,18 @@ gfbgraph_test_fixture_setup (GFBGraphTestFixture *fixture, gconstpointer user_da
 
         fixture->authorizer = gfbgraph_simple_authorizer_new (access_token);
 
-        if (function_path)
-                g_free (function_path);
         g_clear_object (&rest_call);
         g_clear_object (&proxy);
+
 }
 
 static void
-gfbgraph_test_fixture_teardown (GFBGraphTestFixture *fixture, gconstpointer user_data)
+gfbgraph_test_fixture_teardown (GFBGraphTestFixture *fixture, G_GNUC_UNUSED gconstpointer user_data)
 {
-        SoupSession *ssession;
-        SoupMessage *smessage;
-        gchar *function_path;
-        gchar *auth_value;
+        g_autoptr(SoupSession) ssession = NULL;
+        g_autoptr(SoupMessage) smessage = NULL;
+        g_autofree gchar *function_path = NULL;
         guint status;
-        const GFBGraphTestApp *app = user_data;
-        SoupURI *uri;
 
         /* Delete the test user and clean up memory */
 
@@ -195,36 +191,32 @@ gfbgraph_test_fixture_teardown (GFBGraphTestFixture *fixture, gconstpointer user
         status = soup_session_send_message (ssession, smessage);
         g_assert_cmpint(status, ==, 200);
 
-        g_free (function_path);
-        g_free (auth_value);
         g_free (fixture->user_id);
         g_free (fixture->user_email);
         g_object_unref (fixture->authorizer);
 }
 
 static void
-gfbgraph_test_me (GFBGraphTestFixture *fixture, gconstpointer user_data)
+gfbgraph_test_me (GFBGraphTestFixture *fixture, G_GNUC_UNUSED gconstpointer user_data)
 {
-        GFBGraphUser *me;
-        GError *error = NULL;
+        g_autoptr(GFBGraphUser) me = NULL;
+        g_autoptr(GError) error = NULL;
 
         me = gfbgraph_user_get_me (GFBGRAPH_AUTHORIZER (fixture->authorizer), &error);
         g_assert_no_error (error);
         g_assert (GFBGRAPH_IS_USER (me));
 
         g_assert_cmpstr (fixture->user_id, ==, gfbgraph_node_get_id (GFBGRAPH_NODE (me)));
-
         g_assert_cmpstr (fixture->user_email, ==, gfbgraph_user_get_email (me));
-
-        g_object_unref (me);
 }
 
-static void
-gfbgraph_test_album (GFBGraphTestFixture *fixture, gconstpointer user_data)
+static G_GNUC_UNUSED void
+gfbgraph_test_album (GFBGraphTestFixture *fixture, G_GNUC_UNUSED gconstpointer user_data)
 {
         GFBGraphUser *me;
         GFBGraphAlbum *album;
         GError *error = NULL;
+        gboolean result;
 
         me = gfbgraph_user_get_me (GFBGRAPH_AUTHORIZER (fixture->authorizer), &error);
         g_assert_no_error (error);
@@ -234,11 +226,16 @@ gfbgraph_test_album (GFBGraphTestFixture *fixture, gconstpointer user_data)
         album = gfbgraph_album_new ();
         gfbgraph_album_set_name (album, "Vanilla Sky");
         gfbgraph_album_set_description (album, "Great sunset photos in Mars!");
-        g_assert (gfbgraph_node_append_connection (GFBGRAPH_NODE (me),
-                                                   GFBGRAPH_NODE (album),
-                                                   GFBGRAPH_AUTHORIZER (fixture->authorizer),
-                                                   &error));
+        result = gfbgraph_node_append_connection (GFBGRAPH_NODE (me),
+                                                  GFBGRAPH_NODE (album),
+                                                  GFBGRAPH_AUTHORIZER (fixture->authorizer),
+                                                  &error);
+        /* Asserting the connection */
         g_assert_no_error (error);
+        g_assert (result);
+
+        /* Asserting the Album ID */
+        g_assert_cmpstr (gfbgraph_node_get_id (GFBGRAPH_NODE (album)), !=, "");
 }
 
 int
@@ -260,12 +257,14 @@ main (int argc, char **argv)
                     gfbgraph_test_me,
                     gfbgraph_test_fixture_teardown);
 
+#if 0
         g_test_add ("/GFBGraph/Album",
                     GFBGraphTestFixture,
                     app,
                     gfbgraph_test_fixture_setup,
                     gfbgraph_test_album,
                     gfbgraph_test_fixture_teardown);
+#endif
 
         test_result = g_test_run ();
 
@@ -276,6 +275,7 @@ main (int argc, char **argv)
                         g_free (app->client_secret);
                 if (app->access_token)
                         g_free (app->access_token);
+                g_free (app);
         }
 
         return test_result;
